package com.compdfkit.conversion.flutter.plugin

import android.content.Context
import androidx.annotation.NonNull
import com.compdfkit.conversion.CPDFConverter
import com.compdfkit.conversion.flutter.plugin.utils.FileUtils

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result


class ConversionSDKFlutterPlugin : FlutterPlugin, MethodCallHandler {

    private lateinit var channel: MethodChannel

    private var context: Context? = null

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        context = flutterPluginBinding.applicationContext
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "com.compdfkit.conversion.flutter.convert.sdk.info")
        channel.setMethodCallHandler(this)
        flutterPluginBinding.flutterEngine.plugins.add(ConvertFlutterPlugin())
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            "conversion_init" ->{
                result.success(true)
            }
            "request_convert_output_path" -> {
                context?.let {
                    result.success(FileUtils.getOutputFilePath(context = it))
                }
            }
            "sdk_build_tag" -> {
                // return conversion sdk build tag info
                result.success(CPDFConverter.getSDKBuildTag())
            }
            "sdk_version" ->{
                result.success(CPDFConverter.getSDKVersion())
            }
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
        context = null
    }
}
