//
//  CPDFConvertExcelOptions.h
//  ComPDFKit_Conversion
//
//  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
//
//  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
//  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
//  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
//  This notice may not be removed from this file.
//

#import <ComPDFKit_Conversion/CPDFConvertOptions.h>

typedef NS_ENUM(NSInteger, CPDFConvertExcelContentOptions) {
    CPDFConvertExcelContentOnlyText = 0,   // Only extract text in PDF and write it to XLSX without extracting the table.
    CPDFConvertExcelContentOnlyTable = 1,  // Only extract table in PDF and write it to XLSX.
    CPDFConvertExcelContentAllContent = 2  // Extract all content in PDF and write it to XLSX, including table and non-table content.
};

typedef NS_ENUM(NSInteger, CPDFConvertExcelWorksheetOptions) {
    CPDFConvertExcelWorksheetForEachTable = 0,   // Each table in the PDF is converted to one separate Worksheet.
    CPDFConvertExcelWorksheetForEachPage = 1,    // All tables on one page in the PDF are converted to one separate Worksheet.
    CPDFConvertExcelWorksheetForTheDocument = 2  // All tables in the entire PDF are converted to one separate Worksheet.
};

/**
 * PDF to Excel conversion parameter object(derived class of CPDFConvertOptions).
 */
@interface CPDFConvertExcelOptions : CPDFConvertOptions

/**
 * Options to extract content.
 */
@property (nonatomic,assign) CPDFConvertExcelContentOptions contentOptions;

/**
 * Options to create Worksheet.
 */
@property (nonatomic,assign) CPDFConvertExcelWorksheetOptions worksheetOptions;

/**
 * Whether to use OCR.
 */
@property (nonatomic,assign) BOOL isAllowOCR;

/**
 * Whether the OCR background image is contained,this takes effect only when IsAllowOCR is true.
 */
@property (nonatomic,assign) BOOL isContainOCRBgImage;

/**
 * Set the OCR language,this takes effect only when IsAllowOCR is true.
 */
@property (nonatomic,assign) COCRLanguage language;

/**
 * Whether to contain annotations when converting.
 */
@property (nonatomic,assign) BOOL isContainAnnotations;

/**
 * Whether to contain images when converting.
 */
@property (nonatomic,assign) BOOL isContainImages;

@end
