//
//  CPDFConvertHtmlOptions.h
//  ComPDFKit_Conversion
//
//  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
//
//  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
//  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
//  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
//  This notice may not be removed from this file.
//

#import <ComPDFKit_Conversion/CPDFConvertOptions.h>

/**
 * Options to set pages and navigation panes.
 */
typedef NS_ENUM(NSInteger, CPDFConvertHtmlPageAndNavigationPaneOptions) {
    CPDFConvertHtmlSinglePage = 0,                       // Single page with no navigation.
    CPDFConvertHtmlSinglePageNavigationByBookmarks = 1,  // Navigate single page using bookmarks from PDF.
    CPDFConvertHtmlMultiplePages = 2,                    // Multiple pages with no split.
    CPDFConvertHtmlMultiplePagesSplitByBookmarks = 3     // Split multiple pages using bookmarks from PDF.
};

/**
 * PDF to HTML conversion parameter object (derived class of CPDFConvertOptions).
 */
@interface CPDFConvertHtmlOptions : CPDFConvertOptions

/**
 * Sets options to convert PDF to HTML.
 *
 * @see CPDFConvertHtmlPageAndNavigationPaneOptions
 */
@property (nonatomic,assign) CPDFConvertHtmlPageAndNavigationPaneOptions paneOptions;

/**
 * Whether to use OCR.
 */
@property (nonatomic,assign) BOOL isAllowOCR;

/**
 * Set the OCR language,this takes effect only when IsAllowOCR is true.
 */
@property (nonatomic,assign) COCRLanguage language;

/**
 * Whether to contain annotations when converting.
 */
@property (nonatomic,assign) BOOL isContainAnnotations;

/**
 * Whether to contain images when converting.
 */
@property (nonatomic,assign) BOOL isContainImages;

@end
