//
//  CPDFConverterFP.h
//  ComPDFKit_Conversion
//
//  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
//
//  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
//  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
//  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
//  This notice may not be removed from this file.
//

#import <Foundation/Foundation.h>

typedef NSString* const CPDFConvertOptionsKey NS_STRING_ENUM;

extern CPDFConvertOptionsKey CPDFConvertOptionsKeyImageDPI; // NSInteger
extern CPDFConvertOptionsKey CPDFConvertOptionsKeyAllInOneSheet; // BOOL

@protocol CPDFConverterFPDelegate <NSObject>

@optional

// Going to start the transformation
- (void)FPPDFConverter:(id)converter didStartConversion:(NSError *)error;

// Complete the conversion
- (void)FPPDFConverter:(id)converter didEndConversion:(NSError *)error;

// Page progress
- (void)FPPDFConverter:(id)converter
             pageIndex:(NSUInteger)pageIndexA
              progress:(NSUInteger)progress;

// Finish parsing a page
- (void)FPPDFConverter:(id)converter
   convertPDFPageIndex:(NSUInteger)pdfPageIndexA
    writeWordPageIndex:(NSUInteger)wordPageIndexA
  finshedWordPageCount:(NSUInteger)wordPageCountA;

// A page cannot be converted
- (void)FPPDFConverter:(id)converter
   convertPDFPageIndex:(NSUInteger)pdfPageIndexA
        faildWithError:(NSError *)error;

// The document will be saved to disk
- (void)FPPDFConverter:(id)converter willSaveDoc:(NSError *)error;

// Catch an anomaly
- (void)FPPDFConverter:(id)converter
        catchException:(NSException *)exception;

@end

@interface CPDFConverterFP : NSObject

- (instancetype)init;

- (void)setDelegate:(id<CPDFConverterFPDelegate>)delegate;

- (void)convertPDFAtPath:(NSString *)pdfPathA
             pdfPassword:(NSString *)pdfPasswordA
           pdfPageIndexs:(NSArray *)pdfPageIndexsA
             destDocType:(NSString *)destDocTypeA
             destDocPath:(NSString *)destDocPathA
             moreOptions:(NSDictionary<CPDFConvertOptionsKey, id> *)moreOptionsA;

- (void)stopConvertsionIfNeed;

@end
